pub struct RuntimeCombObserver<A> {
pub site_id: u32,
pub activation_group: u32,
pub sensitivity: Vec<VarAtomBase<A>>,
pub written_inputs: Vec<A>,
}Expand description
Runtime activation recipe for one combinational event site.
Expression trees used to emit the event have already been lowered into SIR. The runtime only retains the persistent-state ranges needed to detect whether the corresponding combinational process must be observed again.
Fields
site_id: u32activation_group: u32sensitivity: Vec<VarAtomBase<A>>written_inputs: Vec<A>Trait Implementations
Sourceimpl<A: Clone> Clone for RuntimeCombObserver<A>
impl<A: Clone> Clone for RuntimeCombObserver<A>
Sourcefn clone(&self) -> RuntimeCombObserver<A>
fn clone(&self) -> RuntimeCombObserver<A>
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<A: Debug> Debug for RuntimeCombObserver<A>
impl<A: Debug> Debug for RuntimeCombObserver<A>
Sourceimpl<'de, A> Deserialize<'de> for RuntimeCombObserver<A>where
A: Deserialize<'de>,
impl<'de, A> Deserialize<'de> for RuntimeCombObserver<A>where
A: Deserialize<'de>,
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more