pub struct EventTopology<A> {
pub aliases: FxHashMap<A, A>,
pub ordered_events: Vec<A>,
pub cascaded_events: BTreeSet<A>,
pub reset_clocks: FxHashMap<A, A>,
}Expand description
Source-independent event-domain topology after elaboration.
Addresses are already flattened. Source paths and frontend IDs used only for diagnostics or lookup deliberately live outside this structure.
Fields
aliases: FxHashMap<A, A>Alias event address to the canonical event-domain address.
ordered_events: Vec<A>Canonical event domains in evaluation order.
cascaded_events: BTreeSet<A>Canonical clocks whose value may be changed by another event domain.
reset_clocks: FxHashMap<A, A>Canonical asynchronous/synchronous reset to its canonical clock.
Implementations